editor

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Controller

type Controller struct {
	In       io.Reader
	Out, Err io.Writer
	// contains filtered or unexported fields
}

Controller manages actions related to the editor.

func New

func New(in io.Reader, out, err io.Writer) *Controller

New creates a new Controller.

func (*Controller) OpenFile

func (e *Controller) OpenFile(filepath string) error

OpenFile opens a file in the editor It uses the EDITOR environment variable to determine the editor to use

type Open

type Open interface {
	OpenFile(string) error
}

Directories

Path Synopsis
Package editormock is a generated GoMock package.
Package editormock is a generated GoMock package.

Jump to