entity

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WithSince

func WithSince(t time.Time) func(o *ReporterOptions)

WithSince returns a ReporterOption that sets the Since field.

func WithWriter

func WithWriter(w io.Writer) func(o *ReporterOptions)

WithWriter returns a ReporterOption that sets the Writer field.

Types

type Differential

type Differential struct {
	ID             string
	Title          string
	LineCount      int
	Status         Status
	StatusName     string
	URI            string
	CreatedAt      time.Time
	ModifiedAt     time.Time
	RepositoryPHID string
}

Differential represents a Phabricator Differential. This is a simplified version of the DifferentialRevision entity from gonduit.

type Reporter

type Reporter interface {
	Report([]*User, ...ReporterOption) error
}

type ReporterOption

type ReporterOption func(*ReporterOptions)

ReporterOption represents a functional option for the Reporter.

type ReporterOptions

type ReporterOptions struct {
	// Since is the time to let the Reporter know when to start reporting.
	Since *time.Time
	// Writer is the io.Writer to write the report to.
	Writer io.Writer
}

ReporterOptions represents the options for the Reporter.

type Status

type Status string
const (
	Accepted Status = "accepted"
	Closed   Status = "closed"
	Unknown  Status = "unknown"
)

type User

type User struct {
	Username      string
	Email         string
	ID            string
	Differentials []*Differential
	Reviews       []*Differential
}

User represents a Phabricator User. This is a simplified version of the User entity from gonduit.

Directories

Path Synopsis
Package reportermock is a generated GoMock package.
Package reportermock is a generated GoMock package.

Jump to