Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Controller ¶
type Controller struct {
In io.Reader
Out, Err io.Writer
// contains filtered or unexported fields
}
Controller manages actions related to the editor.
func (*Controller) OpenFile ¶
func (e *Controller) OpenFile(filepath string) error
OpenFile opens a file in the editor It uses the EDITOR environment variable to determine the editor to use
Directories
¶
| Path | Synopsis |
|---|---|
|
Package editormock is a generated GoMock package.
|
Package editormock is a generated GoMock package. |
Click to show internal directories.
Click to hide internal directories.